@@ -1,22 +1,23 @@
 package api
 
-import "github.com/xanzy/go-gitlab"
+import (
+	"github.com/xanzy/go-gitlab"
+)
 
 // CreateSnippet for the user inside the users snippets
 var CreateSnippet = func(
 	client *gitlab.Client,
-	projectID interface{},
 	opts *gitlab.CreateSnippetOptions,
 ) (*gitlab.Snippet, error) {
 	if client == nil {
 		client = apiClient.Lab()
 	}
 
-	snipet, _, err := client.Snippets.CreateSnippet(opts)
+	snippet, _, err := client.Snippets.CreateSnippet(opts)
 	if err != nil {
 		return nil, err
 	}
-	return snipet, err
+	return snippet, err
 }
 
 // CreateProjectSnippet inside the project
@@ -29,9 +30,10 @@ var CreateProjectSnippet = func(
 		client = apiClient.Lab()
 	}
 
-	snipet, _, err := client.ProjectSnippets.CreateSnippet(projectID, opts)
+	snippet, _, err := client.ProjectSnippets.CreateSnippet(projectID, opts)
 	if err != nil {
 		return nil, err
 	}
-	return snipet, err
+
+	return snippet, err
 }
